==> viruskiller_1.0-1.orig.tar.gz: viruskiller-1.0/src/CMath.h <==
/*
Copyright (C) 2004 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

class Math {

	private:

		Math(){}

	public:

	static void limitChar(signed char *in, int low, int high);
	static void limitChar(unsigned char *in, int low, int high);
	static void limitInt(int *in, int low, int high);
	static void limitFloat(float *in, float low, float high);

	static void wrapChar(signed char *in, signed char low, signed char high);
	static void wrapInt(int *in, int low, int high);
	static void wrapFloat(float *in, float low, float high);
	
	static void swap(int *i1, int *i2);
	static void swap(float *f1, float *f2);

	static int rrand(int min, int max);

	static bool boolFromWord(char *word);

	static void addBit(unsigned int *currentBits, int newBits);
	static void removeBit(unsigned int *currentBits, int oldBits);
	static void calculateSlope(float x, float y, float x2, float y2, float *dx, float *dy);
	
};

==> viruskiller_1.03-1+dfsg1.orig.tar.gz: viruskiller-1.03-1+dfsg1/src/CMath.h <==
/*
Copyright (C) 2004 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

class Math {

	private:

		Math(){}

	public:

	static void limitChar(signed char *in, int low, int high);
	static void limitChar(unsigned char *in, int low, int high);
	static void limitInt(int *in, int low, int high);
	static void limitFloat(float *in, float low, float high);

	static void wrapChar(signed char *in, signed char low, signed char high);
	static void wrapInt(int *in, int low, int high);
	static void wrapFloat(float *in, float low, float high);
	
	static void swap(int *i1, int *i2);
	static void swap(float *f1, float *f2);

	static int rrand(int min, int max);

	static bool boolFromWord(const char *word);

	static void addBit(unsigned int *currentBits, int newBits);
	static void removeBit(unsigned int *currentBits, int oldBits);
	static void calculateSlope(float x, float y, float x2, float y2, float *dx, float *dy);
	
};
